@@ -1,7 +1,7 @@
 use strict;
 use warnings;
-package Moose; # git description: 2.2009-11-ga73c5a370
-our $VERSION = '2.2010';
+package Moose; # git description: 2.2200-2-g4572f3741
+our $VERSION = '2.2201';
 our $AUTHORITY = 'cpan:STEVAN';
 
 use 5.008003;
@@ -298,7 +298,7 @@ Moose - A postmodern object system for Perl 5
 
 =head1 VERSION
 
-version 2.2010
+version 2.2201
 
 =head1 SYNOPSIS
 
@@ -855,8 +855,7 @@ metaclass:
 
 This is very similar to the attribute traits feature. When you do
 this, your class's C<meta> object will have the specified traits
-applied to it. See L<Metaclass and Trait Name Resolution> for more
-details.
+applied to it.
 
 =head2 Metaclass and Trait Name Resolution
 
@@ -1111,7 +1110,7 @@ can contribute.
 There are only a few people with the rights to release a new version
 of Moose. The Moose Cabal are the people to go to with questions regarding
 the wider purview of Moose. They help maintain not just the code
-but the community as well. See the list below under C<AUTHORS>.
+but the community as well. See the list below under L</AUTHORS>.
 
 =head1 CONTRIBUTORS
 
@@ -1219,7 +1218,7 @@ Wallace (wreis) Reis
 
 =item *
 
-Stevan Little <stevan.little@iinteractive.com>
+Stevan Little <stevan@cpan.org>
 
 =item *
 
@@ -1227,11 +1226,11 @@ Dave Rolsky <autarch@urth.org>
 
 =item *
 
-Jesse Luehrs <doy@tozt.net>
+Jesse Luehrs <doy@cpan.org>
 
 =item *
 
-Shawn M Moore <code@sartak.org>
+Shawn M Moore <sartak@cpan.org>
 
 =item *
 
@@ -1247,7 +1246,7 @@ Florian Ragwitz <rafl@debian.org>
 
 =item *
 
-Hans Dieter Pearcey <hdp@weftsoar.net>
+Hans Dieter Pearcey <hdp@cpan.org>
 
 =item *
 
@@ -1255,7 +1254,7 @@ Chris Prather <chris@prather.org>
 
 =item *
 
-Matt S Trout <mst@shadowcat.co.uk>
+Matt S Trout <mstrout@cpan.org>
 
 =back
 
