@@ -1,4 +1,3 @@
-
 package # hide the package from PAUSE
     InstanceCountingClass;
 
@@ -61,13 +60,4 @@ Stevan Little E<lt>stevan@iinteractive.comE<gt>
 
 Yuval Kogman E<lt>nothingmuch@woobling.comE<gt>
 
-=head1 COPYRIGHT AND LICENSE
-
-Copyright 2006-2008 by Infinity Interactive, Inc.
-
-L<http://www.iinteractive.com>
-
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
-
 =cut
